/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package DataEntryBean;

/**
 *
 * @author TCS
 */
public class DepositKYCCreationHdrBean {

    private String cif;
    private String cType;
    private String linkedAccount;
    private String title;
    private String fName;
    private String mName;
    private String lName;
    private String gName;
    private String add1;
    private String add2;
    private String add3;
    private String distname;
    private String city;
    private String statename;
    private String dob;
    private String gender;
    private String religion;
    private String caste;
    private String mNumber;
    private String block;
    private String nameOfFile;
    private String file;
    private String motherName;
    private String pin;
    private String ward; //Added for member share report

    public String getEmailId() {
        return emailId;
    }

    public void setEmailId(String emailId) {
        this.emailId = emailId;
    }
    private String sigUpld;
    private String emailId;

    //for update
    private String cifNoAmend;
    private String cTypeAmend;
    private String linkedAccountAmend;
    private String tittleAmend;
    private String fNameAmend;
    private String mNameAmend;
    private String lNameAmend;
    private String gNameAmend;
    private String add1Amend;
    private String add2Amend;
    private String add3Amend;
    private String distnameAmend;
    private String citynameAmend;
    private String statenameAmend;
    private String dobAmend;
    private String genderAmend;
    private String religionAmend;
    private String casteAmend;
    private String mNumberAmend;
    private String blockAmend;
    private String mem_no;
    private String farmerType;
    private String cifName;//used in DepositKYCDocumentUpload.jsp
    private String mem_noAmend;
    private String farmerTypeAmend;
    private String bankCIF;
    private String aliveDead;
    private String doDeath;
    private String lstatus;
    private String motherNameAmend;
    private String pinAmend;
    private String wardAmend; // Added for meber share report
    
    public String getwardAmend(){
        return wardAmend;
    }
    
   public void setwardAmend(String wardAmend) 
   {
       this.wardAmend = wardAmend;
   }

    public String getMotherName() {
        return motherName;
    }

    public void setMotherName(String motherName) {
        this.motherName = motherName;
    }

    public String getPin() {
        return pin;
    }

    public void setPin(String pin) {
        this.pin = pin;
    }

    public String getMotherNameAmend() {
        return motherNameAmend;
    }

    public void setMotherNameAmend(String motherNameAmend) {
        this.motherNameAmend = motherNameAmend;
    }

    public String getPinAmend() {
        return pinAmend;
    }

    public void setPinAmend(String pinAmend) {
        this.pinAmend = pinAmend;
    }

    public String getLstatus() {
        return lstatus;
    }

    public void setLstatus(String lstatus) {
        this.lstatus = lstatus;
    }
    
    public String getAliveDead() {
        return aliveDead;
    }

    public void setAliveDead(String AliveDead) {
        this.aliveDead = AliveDead;
    }

    public String getBankCIF() {
        return bankCIF;
    }

    public void setBankCIF(String bankCIF) {
        this.bankCIF = bankCIF;
    }

    public String getDoDeath() {
        return doDeath;
    }

    public void setDoDeath(String doDeath) {
        this.doDeath = doDeath;
    }

    public String getFarmerTypeAmend() {
        return farmerTypeAmend;
    }

    public void setFarmerTypeAmend(String farmerTypeAmend) {
        this.farmerTypeAmend = farmerTypeAmend;
    }

    public String getMem_noAmend() {
        return mem_noAmend;
    }

    public void setMem_noAmend(String mem_noAmend) {
        this.mem_noAmend = mem_noAmend;
    }

    public String getFarmerType() {
        return farmerType;
    }

    public void setFarmerType(String farmerType) {
        this.farmerType = farmerType;
    }

    public String getMem_no() {
        return mem_no;
    }

    public void setMem_no(String mem_no) {
        this.mem_no = mem_no;
    }
    public String getCasteAmend() {
        return casteAmend;
    }

    public void setCasteAmend(String casteAmend) {
        this.casteAmend = casteAmend;
    }

    public String getReligionAmend() {
        return religionAmend;
    }

    public void setReligionAmend(String religionAmend) {
        this.religionAmend = religionAmend;
    }

    public String getCaste() {
        return caste;
    }

    public void setCaste(String caste) {
        this.caste = caste;
    }

    public String getReligion() {
        return religion;
    }

    public void setReligion(String religion) {
        this.religion = religion;
    }

    public String getSigUpld() {
        return sigUpld;
    }

    public void setSigUpld(String sigUpld) {
        this.sigUpld = sigUpld;
    }

    public String getFile() {
        return file;
    }

    public void setFile(String file) {
        this.file = file;
    }

    public String getNameOfFile() {
        return nameOfFile;
    }

    public void setNameOfFile(String nameOfFile) {
        this.nameOfFile = nameOfFile;
    }


    public String getCifName() {
        return cifName;
    }

    public void setCifName(String cifName) {
        this.cifName = cifName;
    }

    public String getBlock() {
        return block;
    }

    /**
     * @return the idType
     */
    public void setBlock(String block) {
        this.block = block;
    }
    
    public String getWard()
    {
        return ward;
    }
    
    public void setWard(String ward){
        this.ward = ward;
    }
    /**
     * @return the cif
     */
    public String getCif() {
        return cif;
    }

    /**
     * @param cif the cif to set
     */
    public void setCif(String cif) {
        this.cif = cif;
    }

    /**
     * @return the cType
     */
    public String getcType() {
        return cType;
    }

    /**
     * @param cType the cType to set
     */
    public void setcType(String cType) {
        this.cType = cType;
    }

    /**
     * @return the linkedAccount
     */
    public String getLinkedAccount() {
        return linkedAccount;
    }

    /**
     * @param linkedAccount the linkedAccount to set
     */
    public void setLinkedAccount(String linkedAccount) {
        this.linkedAccount = linkedAccount;
    }

    /**
     * @return the tittle
     */
    public String getTitle() {
        return title;
    }

    /**
     * @param tittle the tittle to set
     */
    public void setTitle(String title) {
        this.title = title;
    }

    /**
     * @return the fName
     */
    public String getfName() {
        return fName;
    }

    /**
     * @param fName the fName to set
     */
    public void setfName(String fName) {
        this.fName = fName;
    }

    /**
     * @return the mName
     */
    public String getmName() {
        return mName;
    }

    /**
     * @param mName the mName to set
     */
    public void setmName(String mName) {
        this.mName = mName;
    }

    /**
     * @return the lName
     */
    public String getlName() {
        return lName;
    }

    /**
     * @param lName the lName to set
     */
    public void setlName(String lName) {
        this.lName = lName;
    }

    /**
     * @return the gName
     */
    public String getgName() {
        return gName;
    }

    /**
     * @param gName the gName to set
     */
    public void setgName(String gName) {
        this.gName = gName;
    }

    /**
     * @return the add1
     */
    public String getAdd1() {
        return add1;
    }

    /**
     * @param add1 the add1 to set
     */
    public void setAdd1(String add1) {
        this.add1 = add1;
    }

    /**
     * @return the add2
     */
    public String getAdd2() {
        return add2;
    }

    /**
     * @param add2 the add2 to set
     */
    public void setAdd2(String add2) {
        this.add2 = add2;
    }

    /**
     * @return the add3
     */
    public String getAdd3() {
        return add3;
    }

    /**
     * @param add3 the add3 to set
     */
    public void setAdd3(String add3) {
        this.add3 = add3;
    }

    /**
     * @return the distname
     */
    public String getDistname() {
        return distname;
    }

    /**
     * @param distname the distname to set
     */
    public void setDistname(String distname) {
        this.distname = distname;
    }

    /**
     * @return the cityname
     */
    public String getCity() {
        return city;
    }

    /**
     * @param cityname the cityname to set
     */
    public void setCity(String city) {
        this.city = city;
    }

    /**
     * @return the statename
     */
    public String getStatename() {
        return statename;
    }

    /**
     * @param statename the statename to set
     */
    public void setStatename(String statename) {
        this.statename = statename;
    }

    /**
     * @return the dob
     */
    public String getDob() {
        return dob;
    }

    /**
     * @param dob the dob to set
     */
    public void setDob(String dob) {
        this.dob = dob;
    }

    /**
     * @return the gender
     */
    public String getGender() {
        return gender;
    }

    /**
     * @param gender the gender to set
     */
    public void setGender(String gender) {
        this.gender = gender;
    }

    /**
     * @return the mNumber
     */
    public String getmNumber() {
        return mNumber;
    }

    /**
     * @param mNumber the mNumber to set
     */
    public void setmNumber(String mNumber) {
        this.mNumber = mNumber;
    }

    public String getAdd1Amend() {
        return add1Amend;
    }

    public void setAdd1Amend(String add1Amend) {
        this.add1Amend = add1Amend;
    }

    public String getAdd2Amend() {
        return add2Amend;
    }

    public void setAdd2Amend(String add2Amend) {
        this.add2Amend = add2Amend;
    }

    public String getAdd3Amend() {
        return add3Amend;
    }

    public void setAdd3Amend(String add3Amend) {
        this.add3Amend = add3Amend;
    }

    public String getBlockAmend() {
        return blockAmend;
    }

    public void setBlockAmend(String blockAmend) {
        this.blockAmend = blockAmend;
    }

    public String getcTypeAmend() {
        return cTypeAmend;
    }

    public void setcTypeAmend(String cTypeAmend) {
        this.cTypeAmend = cTypeAmend;
    }

    public String getCifNoAmend() {
        return cifNoAmend;
    }

    public void setCifNoAmend(String cifNoAmend) {
        this.cifNoAmend = cifNoAmend;
    }

    public String getCitynameAmend() {
        return citynameAmend;
    }

    public void setCitynameAmend(String citynameAmend) {
        this.citynameAmend = citynameAmend;
    }

    public String getDistnameAmend() {
        return distnameAmend;
    }

    public void setDistnameAmend(String distnameAmend) {
        this.distnameAmend = distnameAmend;
    }

    public String getDobAmend() {
        return dobAmend;
    }

    public void setDobAmend(String dobAmend) {
        this.dobAmend = dobAmend;
    }

    public String getfNameAmend() {
        return fNameAmend;
    }

    public void setfNameAmend(String fNameAmend) {
        this.fNameAmend = fNameAmend;
    }

    public String getgNameAmend() {
        return gNameAmend;
    }

    public void setgNameAmend(String gNameAmend) {
        this.gNameAmend = gNameAmend;
    }

    public String getGenderAmend() {
        return genderAmend;
    }

    public void setGenderAmend(String genderAmend) {
        this.genderAmend = genderAmend;
    }

    public String getlNameAmend() {
        return lNameAmend;
    }

    public void setlNameAmend(String lNameAmend) {
        this.lNameAmend = lNameAmend;
    }

    public String getLinkedAccountAmend() {
        return linkedAccountAmend;
    }

    public void setLinkedAccountAmend(String linkedAccountAmend) {
        this.linkedAccountAmend = linkedAccountAmend;
    }

    public String getmNameAmend() {
        return mNameAmend;
    }

    public void setmNameAmend(String mNameAmend) {
        this.mNameAmend = mNameAmend;
    }

    public String getmNumberAmend() {
        return mNumberAmend;
    }

    public void setmNumberAmend(String mNumberAmend) {
        this.mNumberAmend = mNumberAmend;
    }

    public String getStatenameAmend() {
        return statenameAmend;
    }

    public void setStatenameAmend(String statenameAmend) {
        this.statenameAmend = statenameAmend;
    }

    public String getTittleAmend() {
        return tittleAmend;
    }

    public void setTittleAmend(String tittleAmend) {
        this.tittleAmend = tittleAmend;
    }




}
